#[non_exhaustive]pub struct EncodingConfigBuilder { /* private fields */ }Expand description
A builder for EncodingConfig.
Implementations
Sourceimpl EncodingConfigBuilder
impl EncodingConfigBuilder
Sourcepub fn encoding_profile(self, input: EncodingProfile) -> Self
pub fn encoding_profile(self, input: EncodingProfile) -> Self
The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.
Sourcepub fn set_encoding_profile(self, input: Option<EncodingProfile>) -> Self
pub fn set_encoding_profile(self, input: Option<EncodingProfile>) -> Self
The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.
Sourcepub fn get_encoding_profile(&self) -> &Option<EncodingProfile>
pub fn get_encoding_profile(&self) -> &Option<EncodingProfile>
The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.
Sourcepub fn video_max_bitrate(self, input: i32) -> Self
pub fn video_max_bitrate(self, input: i32) -> Self
The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.
The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.
Sourcepub fn set_video_max_bitrate(self, input: Option<i32>) -> Self
pub fn set_video_max_bitrate(self, input: Option<i32>) -> Self
The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.
The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.
Sourcepub fn get_video_max_bitrate(&self) -> &Option<i32>
pub fn get_video_max_bitrate(&self) -> &Option<i32>
The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.
The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.
Sourcepub fn build(self) -> EncodingConfig
pub fn build(self) -> EncodingConfig
Consumes the builder and constructs a EncodingConfig.