EncodingConfig

Struct EncodingConfig 

#[non_exhaustive]
pub struct EncodingConfig { pub encoding_profile: Option<EncodingProfile>, pub video_max_bitrate: Option<i32>, }
The encoding configuration to apply to the NDI® source when transcoding it to a transport stream for downstream distribution. You can choose between several predefined encoding profiles based on common use cases.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
encoding_profile: Option<EncodingProfile>

The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.

video_max_bitrate: Option<i32>

The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.

The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.

Implementations

Source

impl EncodingConfig

pub fn encoding_profile(&self) -> Option<&EncodingProfile>

The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.

pub fn video_max_bitrate(&self) -> Option<i32>

The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.

The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.

Source

impl EncodingConfig

pub fn builder() -> EncodingConfigBuilder

Creates a new builder-style object to manufacture EncodingConfig.