#[non_exhaustive]pub struct MediaLiveChannelRouterInputConfiguration {
pub media_live_channel_arn: Option<String>,
pub media_live_pipeline_id: Option<MediaLiveChannelPipelineId>,
pub media_live_channel_output_name: Option<String>,
pub source_transit_decryption: Option<MediaLiveTransitEncryption>,
}Expand description
Configuration settings for connecting a router input to a MediaLive channel output.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.media_live_channel_arn: Option<String>The ARN of the MediaLive channel to connect to this router input.
media_live_pipeline_id: Option<MediaLiveChannelPipelineId>The index of the MediaLive pipeline to connect to this router input.
media_live_channel_output_name: Option<String>The name of the MediaLive channel output to connect to this router input.
source_transit_decryption: Option<MediaLiveTransitEncryption>The encryption configuration that defines how content is encrypted during transit between MediaConnect Router and MediaLive. This configuration determines whether encryption keys are automatically managed by the service or manually managed through Secrets Manager.
Implementations
Sourceimpl MediaLiveChannelRouterInputConfiguration
impl MediaLiveChannelRouterInputConfiguration
Sourcepub fn media_live_channel_arn(&self) -> Option<&str>
pub fn media_live_channel_arn(&self) -> Option<&str>
The ARN of the MediaLive channel to connect to this router input.
Sourcepub fn media_live_pipeline_id(&self) -> Option<&MediaLiveChannelPipelineId>
pub fn media_live_pipeline_id(&self) -> Option<&MediaLiveChannelPipelineId>
The index of the MediaLive pipeline to connect to this router input.
Sourcepub fn media_live_channel_output_name(&self) -> Option<&str>
pub fn media_live_channel_output_name(&self) -> Option<&str>
The name of the MediaLive channel output to connect to this router input.
Sourcepub fn source_transit_decryption(&self) -> Option<&MediaLiveTransitEncryption>
pub fn source_transit_decryption(&self) -> Option<&MediaLiveTransitEncryption>
The encryption configuration that defines how content is encrypted during transit between MediaConnect Router and MediaLive. This configuration determines whether encryption keys are automatically managed by the service or manually managed through Secrets Manager.
Sourceimpl MediaLiveChannelRouterInputConfiguration
impl MediaLiveChannelRouterInputConfiguration
Sourcepub fn builder() -> MediaLiveChannelRouterInputConfigurationBuilder
pub fn builder() -> MediaLiveChannelRouterInputConfigurationBuilder
Creates a new builder-style object to manufacture MediaLiveChannelRouterInputConfiguration.