#[non_exhaustive]pub struct EncodingConfig {
pub encoding_profile: Option<EncodingProfile>,
pub video_max_bitrate: Option<i32>,
}Expand description
The encoding configuration to apply to the NDI® source when transcoding it to a transport stream for downstream distribution. You can choose between several predefined encoding profiles based on common use cases.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encoding_profile: Option<EncodingProfile>The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.
video_max_bitrate: Option<i32>The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.
The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.
Implementations
Sourceimpl EncodingConfig
impl EncodingConfig
Sourcepub fn encoding_profile(&self) -> Option<&EncodingProfile>
pub fn encoding_profile(&self) -> Option<&EncodingProfile>
The encoding profile to use when transcoding the NDI source content to a transport stream. You can change this value while the flow is running.
Sourcepub fn video_max_bitrate(&self) -> Option<i32>
pub fn video_max_bitrate(&self) -> Option<i32>
The maximum video bitrate to use when transcoding the NDI source to a transport stream. This parameter enables you to override the default video bitrate within the encoding profile's supported range.
The supported range is 10,000,000 - 50,000,000 bits per second (bps). If you don't specify a value, MediaConnect uses the default value of 20,000,000 bps.
Sourceimpl EncodingConfig
impl EncodingConfig
Sourcepub fn builder() -> EncodingConfigBuilder
pub fn builder() -> EncodingConfigBuilder
Creates a new builder-style object to manufacture EncodingConfig.